Learn R Programming

ractivecampaign (version 0.6.0)

ac_get_accounts: Retrieve all existing account

Description

Retrieve all existing account

Usage

ac_get_accounts(search = NULL, count_deals = FALSE)

Value

tibble with account list

Arguments

search

Search by name

count_deals

Whether to compute the contactCount and dealCount counts for the number of contacts/deals associated with each account. Set it to true to include the right counts. If set to false or omitted from the call, then contactCount and dealCount will not be counted and be simply displayed as 0.

See Also

Examples

Run this code
if (FALSE) {
Sys.setenv('ACTIVECAMPAGN_API_TOKEN' = "YOUR_TOKEN")
Sys.setenv('ACTIVECAMPAGN_API_URL' = "https://.api-us1.com")

my_accounts <- ac_get_accounts(search = 'name')
}

Run the code above in your browser using DataLab