Contacts are the center of activity in 'ActiveCampaign' and represent the people that the owner of an 'ActiveCampaign' account is marketing to or selling to.
ac_get_contacts(
ids = NULL,
email = NULL,
email_like = NULL,
exclude = NULL,
formid = NULL,
id_greater = NULL,
id_less = NULL,
listid = NULL,
search = NULL,
segmentid = NULL,
seriesid = NULL,
status = NULL,
tagid = NULL,
created_before = NULL,
created_after = NULL,
updated_before = NULL,
updated_after = NULL,
waitid = NULL,
in_group_lists = NULL
)tibble with contacts metadata
Filter contacts by ID. Can be repeated for multiple IDs.
Email address of the contact you want to get
Filter contacts that contain the given value in the email address
Exclude from the response the contact with the given ID
Filter contacts associated with the given form
Only include contacts with an ID greater than the given ID
Only include contacts with an ID less than the given ID
Filter contacts associated with the given list
Filter contacts that match the given value in the contact names, organization, phone or email
Return only contacts that match a list segment (this param initially returns segment information, when it is run a second time it will return contacts that match the segment)
Filter contacts associated with the given automation
Filter contact by status: -1 - Any, 0 - Unconfirmed, 1 - Active, 2 - Unsubscribed, 3 - Bounced
Filter contacts associated with the given tag
Filter contacts that were created prior to this date
Filter contacts that were created after this date
Filter contacts that were updated before this date
Filter contacts that were updated after this date
Filter by contacts in the wait queue of an automation block
Set this to TRUE in order to return only contacts that the current user has permissions to see.
if (FALSE) {
Sys.setenv('ACTIVECAMPAGN_API_TOKEN' = "YOUR_TOKEN")
Sys.setenv('ACTIVECAMPAGN_API_URL' = "https://.api-us1.com")
contacts <- ac_get_contacts()
}
Run the code above in your browser using DataLab