Learn R Programming

ractivecampaign (version 0.6.0)

ac_get_deal_piplines: Retrieve all existing pipelines

Description

Retrieve all existing pipelines

Usage

ac_get_deal_piplines(title = NULL, have_stages = NULL)

Value

tibble with pipline dictionary

Arguments

title

Filter by pipeline's title. The filter matches any pipeline titles that contain the provided title (i.e. "Contact" matches all of "In Contact", "To Contact", and "Contact Pipeline").

have_stages

Filter by whether pipelines have deal stages. Can be either 1 or 0. If 1, only pipelines with at least one stage will be returned.

Examples

Run this code
if (FALSE) {
Sys.setenv('ACTIVECAMPAGN_API_TOKEN' = "YOUR_TOKEN")
Sys.setenv('ACTIVECAMPAGN_API_URL' = "https://.api-us1.com")

deal_piplines <- ac_get_deal_piplines()
}

Run the code above in your browser using DataLab