Retrieve all existing deals
ac_get_deals(
search = NULL,
search_field = NULL,
title = NULL,
stage = NULL,
group = NULL,
status = NULL,
owner = NULL,
nextdate_range = NULL,
tag = NULL,
tasktype = NULL,
created_before = NULL,
created_after = NULL,
updated_before = NULL,
updated_after = NULL,
organization = NULL,
minimum_value = NULL,
maximum_value = NULL,
score_greater_than = NULL,
score_less_than = NULL,
score = NULL
)tibble with deals data
Search text to use with search_field parameter.
Field to search for. Available values: all (All three fields: title, contact, and org), title (Deal's title), contact (Deal's primary contact's first name and last name. If search parameter has more than one word, first word is used for matching first name of contacts and rest of the words are used for matching last name of contacts.), org (Deal's primary contact's organization name).
Filter by deal's title
Filter by deal's stage
Filter by deal's pipeline
Filter by deal's status. 0 - Open, 1 - Won, 2 - Lose.
Filter by deal's owner
Filter by deal's tasks due dates. Available values: upcoming (Deals with tasks that are due within 24 hours.), scheduled (Deals with tasks that are due in more than 24 hours), overdue (Deals with tasks that are past due dates.), no-task (Deals without any task.).
Filter by tag names associated with deal's primary contact. Available values: greater than 0 (Deals with primary contacts that have the tag with given id), -1 (Deals with primary contacts that have any tag), -2 (Deals with primary contacts that have no tag)
Filter by deals that have tasks with given type
Returns deals that are created less than given date
Returns deals that are created greater than or equal to given date
Returns deals that are updated less than given date
Returns deals that are updated greater than or equal to given date
Filter by deal's primary contact's organization's id
In USD with dollar portion. Returns deals whose values are greater than or equal to given
In USD with dollar portion. Returns deals whose values are less than or equal to given
In a format of <score_id>:<score_value>. Returns deals whose score value is greater than given value
In a format of <score_id>:<score_value>. Returns deals whose score value is less than given value
In a format of <score_id>:<score_value>. Returns deals whose score value is equal to given value
if (FALSE) {
Sys.setenv('ACTIVECAMPAGN_API_TOKEN' = "YOUR_TOKEN")
Sys.setenv('ACTIVECAMPAGN_API_URL' = "https://.api-us1.com")
deals <- ac_get_deals()
}
Run the code above in your browser using DataLab