Retrieve a list of existing tasks
ac_get_tasks(
title = NULL,
reltype = NULL,
relid = NULL,
status = NULL,
note = NULL,
duedate = NULL,
d_tasktypeid = NULL,
userid = NULL,
due_after = NULL,
due_before = NULL,
duedate_range = NULL,
assignee_userid = NULL,
outcome_id = NULL
)tibble with tasks data
character, The title to be assigned to the task.
character, The name of the relating object (see relationships table).
integer, The id of the relational object for this task.
integer, Task status means complete or incomplete. 1 is complete and 0 is incomplete.
character, The content describing the task.
date, Due date of the task.
integer, The type of the task based on the available Task Types in the account.
integer, User ID this task belongs to.
character, Filter deal tasks that are due after a specific date.
character, Filter deal tasks that are due before a specific date.
character, Filter deal tasks that are due between specific date range.
integer, The id of the user a task is assigned to.
integer The id of a task outcome that the task belongs to.